@@ -701,9 +701,7 @@ def bitsval(bitfield: bytes, position: int, length: int) -> int:
     if position + length > lbb:
         return None
 
-    return (
-        int.from_bytes(bitfield, "big") >> (lbb - position - length) & 2**length - 1
-    )
+    return int.from_bytes(bitfield, "big") >> (lbb - position - length) & 2**length - 1
 
 
 def parse_rxmspartnkey(msg: UBXMessage) -> list:
