@@ -1,5 +1,7 @@
 """
-UBX Configuration widget for user-selected CFG command
+ubx_dynamic_frame.py
+
+UBX Configuration widget for user-selected CFG command.
 
 Allows user to receive and update configuration for any legacy CFG-*
 command supported by the device which is not already supported by
@@ -63,12 +65,12 @@ from .globals import (
     UBX_CFGOTHER,
 )
 from .helpers import stringvar2val
-from .strings import LBLCFGDYN
+from .strings import LBLCFGGENERIC
 
 # dimensions of scrollable attribute window
 SCROLLX = 300
 SCROLLY = 300
-# following CFG types exluded from selection...
+# following CFG types excluded from selection...
 CFG_EXCLUDED = (
     "CFG-DAT-NUM",  # deprecated
     "CFG-GEOFENCE",  # 'variable by size' groups not yet implemented - use pyubx2
@@ -122,7 +124,7 @@ class UBX_Dynamic_Frame(Frame):
         Set up frame and widgets.
         """
 
-        self._lbl_cfg_dyn = Label(self, text=LBLCFGDYN, anchor="w")
+        self._lbl_cfg_dyn = Label(self, text=LBLCFGGENERIC, anchor="w")
         self._lbx_cfg_cmd = Listbox(
             self,
             border=2,
