@@ -368,9 +368,9 @@ class UBXHandler:
         """
 
         if data.version == 0x00:
-            n = data.relPosN + data.relPosHPN * 1e-1
-            e = data.relPosE + data.relPosHPE * 1e-1
-            d = data.relPosD + data.relPosHPD * 1e-1
+            n = data.relPosN
+            e = data.relPosE
+            d = data.relPosD
             relPosLength, relPosHeading = ned2vector(n, e, d)
             n = data.accN * 1e-2
             e = data.accE * 1e-2
@@ -379,7 +379,7 @@ class UBXHandler:
             accHeading = accLength * relPosHeading / relPosLength  # ballpark
         else:
             relPosLength, relPosHeading, accLength, accHeading = (
-                data.relPosLength + data.relPosHPLength * 1e-1,
+                data.relPosLength,
                 data.relPosHeading,
                 data.accLength * 1e-2,
                 data.accHeading,
