@@ -1,4 +1,6 @@
 """
+ubx_preset_frame.py
+
 UBX Configuration frame for preset and user-defined commands
 
 Created on 22 Dec 2020
@@ -31,6 +33,8 @@ from pygpsclient.globals import (
     ICON_PENDING,
     ICON_SEND,
     ICON_WARNING,
+    RCVR_CONNECTION,
+    SAVED_CONFIG,
     UBX_PRESET,
 )
 from pygpsclient.helpers import ConfirmBox
@@ -107,6 +111,8 @@ class UBX_PRESET_Frame(Frame):
         self.__app = app  # Reference to main application class
         self.__master = self.__app.appmaster  # Reference to root class (Tk)
         self.__container = container
+        # saved_config just contains user presets...
+        self._saved_config = kwargs.pop(SAVED_CONFIG, [])
 
         Frame.__init__(self, self.__container.container, *args, **kwargs)
 
@@ -184,18 +190,15 @@ class UBX_PRESET_Frame(Frame):
 
     def reset(self):
         """
-        Reset panel.
+        Reset panel - Load user-defined presets if there are any.
         """
 
-        # Load user-defined presets if there are any
-        self._userpresets = self.__app.app_config.get("ubxpresets", [])
-
         idx = 0
         for pst in PRESET_COMMMANDS:
             self._lbx_preset.insert(idx, pst)
             idx += 1
 
-        for upst in self._userpresets:
+        for upst in self._saved_config:
             self._lbx_preset.insert(idx, "USER " + upst)
             idx += 1
 
@@ -218,7 +221,7 @@ class UBX_PRESET_Frame(Frame):
             if self._preset_command == PSTRESET:
                 status = self._do_factory_reset()
             elif self._preset_command == PSTSAVE:
-                status = self._do_save_config()
+                status = self._do_store_config()
             elif self._preset_command == PSTMINNMEAON:
                 self._do_set_minnmea()
             elif self._preset_command == PSTALLNMEAON:
@@ -406,16 +409,14 @@ class UBX_PRESET_Frame(Frame):
 
     def _do_set_minNAV(self):
         """
-        Turn on minimum set of UBX-NAV messages (PVT & SVINFO).
+        Turn on minimum set of UBX-NAV messages (DOP, PVT, & SAT).
         """
 
         for msgtype in UBX_MSGIDS:
             if msgtype[0:1] == b"\x01":  # UBX-NAV
                 if msgtype == b"\x01\x07":  # NAV-PVT
                     self._do_cfgmsg(msgtype, 1)
-                #                 elif msgtype == b"\x01\x30":  # NAV-SVINFO (deprecated)
-                #                     self._do_cfgmsg(msgtype, 4)
-                elif msgtype == b"\x01\x35":  # NAV-SAT
+                elif msgtype in (b"\x01\x04", b"\x01\x35"):  # NAV-DOP, NAV-SAT
                     self._do_cfgmsg(msgtype, 4)
                 else:
                     self._do_cfgmsg(msgtype, 0)
@@ -446,26 +447,37 @@ class UBX_PRESET_Frame(Frame):
         """
         Set rate for specified message type via CFG-MSG.
 
-        NB A rate of n means 'for every nth position solution',
-        so values > 1 mean the message is sent less often.
+        The receiver ports to which the rate applies are defined
+        in the `defaultport_s` configuration setting.
 
         :param str msgtype: type of config message
         :param int msgrate: message rate (i.e. every nth position solution)
         """
 
-        msgClass = int.from_bytes(msgtype[0:1], "little", signed=False)
-        msgID = int.from_bytes(msgtype[1:2], "little", signed=False)
+        msgclass = int.from_bytes(msgtype[0:1], "little", signed=False)
+        msgid = int.from_bytes(msgtype[1:2], "little", signed=False)
+
+        # select which receiver ports to apply rate to
+        rates = {}
+        prts = self.__app.frm_settings.config.get(
+            "defaultport_s",
+            self.__app.frm_settings.config.get("defaultport", RCVR_CONNECTION),
+        ).split(",")
+        for prt in prts:
+            rates[prt] = msgrate
+
+        # create CFG-MSG command
         msg = UBXMessage(
             "CFG",
             "CFG-MSG",
             SET,
-            msgClass=msgClass,
-            msgID=msgID,
-            rateDDC=msgrate,
-            rateUART1=msgrate,
-            rateUART2=msgrate,
-            rateUSB=msgrate,
-            rateSPI=msgrate,
+            msgClass=msgclass,
+            msgID=msgid,
+            rateDDC=rates.get("I2C", 0),
+            rateUART1=rates.get("UART1", 0),
+            rateUART2=rates.get("UART2", 0),
+            rateUSB=rates.get("USB", 0),
+            rateSPI=rates.get("SPI", 0),
         )
         self.__container.send_command(msg)
 
@@ -495,9 +507,9 @@ class UBX_PRESET_Frame(Frame):
 
         return CANCELLED
 
-    def _do_save_config(self) -> bool:
+    def _do_store_config(self) -> bool:
         """
-        Save current configuration to persistent storage
+        Store current configuration in persistent storage
         but display confirmation message box first.
 
         :return: boolean signifying whether OK was pressed
